@@ -9,7 +9,7 @@ package Lemonldap::NG::Manager::_i18n;
 
 use strict;
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '0.992';
+our $VERSION = '1.0.0';
 
 ## @method string translate(string text,string lang)
 # Returns $text translated in $lang.
@@ -78,7 +78,6 @@ sub en {
         authParams          => 'Authentication modules',
         dbiAuthChain        => 'Chain',
         dbiAuthLoginCol     => 'Login field name',
-        dbiAuthMailCol      => 'Mail field name',
         dbiAuthnLevel       => 'Authentication level',
         dbiAuthPassword     => 'Password',
         dbiAuthPasswordCol  => 'Password field name',
@@ -90,6 +89,7 @@ sub en {
         dbiConnectionUser   => 'User process',
         dbiParams           => 'DBI parameters',
         dbiPassword         => 'Password',
+        dbiPasswordMailCol  => 'Mail field name',
         dbiSchema           => 'Schema',
         dbiUserChain        => 'Chain',
         dbiUserPassword     => 'Password',
@@ -133,7 +133,7 @@ sub en {
         grantSessionRule             => 'Opening conditions',
         groups                       => 'Groups',
         headers                      => 'HTTP Headers',
-        https                        => 'Default value for https parameter',
+        https                        => 'HTTPS',
         ipAddr                       => 'IP address',
         issuerParams                 => 'Issuer modules',
         issuerDBSAML                 => 'SAML',
@@ -291,15 +291,16 @@ sub en {
         userDB                       => 'Users module',
         userControl                  => 'Username control',
         userPivot                    => 'Login field name in user table',
-        useRedirectOnError           => 'Redirect on handler error',
+        useRedirectOnError           => 'Redirect on error',
         useRedirectOnForbidden       => 'Redirect on forbidden',
-        useXForwardedForIP           => "Use X-Forwarded-For header address",
+        useXForwardedForIP           => "Use X-Forwarded-For",
         variables                    => "Variables",
         vhostHttps                   => 'HTTPS',
         vhostOptions                 => 'Options',
         vhostPort                    => 'Port',
         virtualHosts                 => 'Virtual Hosts',
-        whatToTrace                  => "REMOTE_USER environment variable",
+        warning                      => 'Warning',
+        whatToTrace                  => "REMOTE_USER",
         xForwardedForAddr            => 'Forwarded IP address',
         zimbraAccountKey             => 'Account session key',
         zimbraBy                     => 'Account type',
@@ -460,7 +461,6 @@ sub fr {
         authParams          => "Modules d'authentification",
         dbiAuthChain        => 'Chaîne',
         dbiAuthLoginCol     => 'Champ identifiant',
-        dbiAuthMailCol      => 'Champ mail',
         dbiAuthnLevel       => 'Niveau d\'authentification',
         dbiAuthPassword     => 'Mot de passe',
         dbiAuthPasswordCol  => 'Champ mot de passe',
@@ -472,6 +472,7 @@ sub fr {
         dbiConnectionUser   => 'Utilisateurs',
         dbiParams           => 'Paramètres DBI',
         dbiPassword         => 'Mot de passe',
+        dbiPasswordMailCol  => 'Champ mail',
         dbiSchema           => 'Schéma',
         dbiUserChain        => 'Chaîne',
         dbiUserPassword     => 'Mot de passe',
@@ -515,7 +516,7 @@ sub fr {
         grantSessionRule            => "Conditions d'ouverture",
         groups                      => 'Groupes',
         headers                     => 'En-têtes HTTP',
-        https                       => 'Valeur par défaut du paramètre https',
+        https                        => 'HTTPS',
         ipAddr                      => 'Adresse IP',
         issuerParams                => 'Modules fournisseur',
         issuerDBSAML                => 'SAML',
@@ -674,22 +675,22 @@ sub fr {
         userDB            => "Module d'utilisateurs",
         userControl       => "Contrôle du nom d'utilisateur",
         userPivot         => 'Champ identifiant dans la table des utilisateurs',
-        useRedirectOnError     => 'Redirection pour les erreurs d\'agent',
+        useRedirectOnError     => 'Redirection pour les erreurs',
         useRedirectOnForbidden => 'Redirection pour les accès interdits',
-        useXForwardedForIP =>
-          "Utiliser l'adresse IP de l'en-tête X-Forwarded-For",
+        useXForwardedForIP     => "Utiliser X-Forwarded-For",
         variables         => "Variables",
         vhostHttps        => 'HTTPS',
         vhostOptions      => 'Options',
         vhostPort         => 'Port',
         virtualHosts      => 'Hôtes virtuels',
-        whatToTrace       => "Variable d'environnement REMOTE_USER",
+        warning                => 'Attention',
+        whatToTrace            => "REMOTE_USER",
         xForwardedForAddr => 'Adresse IP transférée',
         zimbraAccountKey  => 'Clé de session pour le compte',
         zimbraBy          => 'Type de compte',
         zimbraHandler     => 'Zimbra',
         zimbraPreAuthKey  => 'Clé de préauthentication',
-        zimbraSsoUrl      => 'Motif pour l\' URL de SSO locale ',
+        zimbraSsoUrl           => 'Motif pour l\'URL de SSO locale ',
         zimbraUrl         => 'URL de préauthentification',
 
         saml                               => 'SAML',
